@@ -10,7 +10,7 @@ import (
 // Add effective field of Dzyaloshinskii-Moriya interaction to Beff (Tesla).
 // According to Bogdanov and Röβler, PRL 87, 3, 2001. eq.8 (out-of-plane symmetry breaking).
 // See dmi.cu
-func AddDMI(Beff *data.Slice, m *data.Slice, Aex_red, Dex_red SymmLUT, Msat MSlice, regions *Bytes, mesh *data.Mesh, OpenBC bool) {
+func AddDMI(Beff *data.Slice, m *data.Slice, Aex, Dex SymmLUT, Msat MSlice, regions *Bytes, mesh *data.Mesh, OpenBC bool) {
 	cellsize := mesh.CellSize()
 	N := Beff.Size()
 	util.Argument(m.Size() == N)
@@ -23,6 +23,6 @@ func AddDMI(Beff *data.Slice, m *data.Slice, Aex_red, Dex_red SymmLUT, Msat MSli
 	k_adddmi_async(Beff.DevPtr(X), Beff.DevPtr(Y), Beff.DevPtr(Z),
 		m.DevPtr(X), m.DevPtr(Y), m.DevPtr(Z),
 		Msat.DevPtr(0), Msat.Mul(0),
-		unsafe.Pointer(Aex_red), unsafe.Pointer(Dex_red), regions.Ptr,
+		unsafe.Pointer(Aex), unsafe.Pointer(Dex), regions.Ptr,
 		float32(cellsize[X]), float32(cellsize[Y]), float32(cellsize[Z]), N[X], N[Y], N[Z], mesh.PBC_code(), openBC, cfg)
 }
