@@ -10,10 +10,10 @@ import (
 //
 //	m: normalized magnetization
 //	B: effective field in Tesla
-//	Aex_red: Aex / (Msat * 1e18 m2)
+//	Aex: exchange stiffness
 //
 // see exchange.cu
-func AddExchange(B, m *data.Slice, Aex_red SymmLUT, Msat MSlice, regions *Bytes, mesh *data.Mesh) {
+func AddExchange(B, m *data.Slice, Aex SymmLUT, Msat MSlice, regions *Bytes, mesh *data.Mesh) {
 	c := mesh.CellSize()
 	wx := float32(2 / (c[X] * c[X]))
 	wy := float32(2 / (c[Y] * c[Y]))
@@ -24,12 +24,12 @@ func AddExchange(B, m *data.Slice, Aex_red SymmLUT, Msat MSlice, regions *Bytes,
 	k_addexchange_async(B.DevPtr(X), B.DevPtr(Y), B.DevPtr(Z),
 		m.DevPtr(X), m.DevPtr(Y), m.DevPtr(Z),
 		Msat.DevPtr(0), Msat.Mul(0),
-		unsafe.Pointer(Aex_red), regions.Ptr,
+		unsafe.Pointer(Aex), regions.Ptr,
 		wx, wy, wz, N[X], N[Y], N[Z], pbc, cfg)
 }
 
 // Finds the average exchange strength around each cell, for debugging.
-func ExchangeDecode(dst *data.Slice, Aex_red SymmLUT, regions *Bytes, mesh *data.Mesh) {
+func ExchangeDecode(dst *data.Slice, Aex SymmLUT, regions *Bytes, mesh *data.Mesh) {
 	c := mesh.CellSize()
 	wx := float32(2 / (c[X] * c[X]))
 	wy := float32(2 / (c[Y] * c[Y]))
@@ -37,5 +37,5 @@ func ExchangeDecode(dst *data.Slice, Aex_red SymmLUT, regions *Bytes, mesh *data
 	N := mesh.Size()
 	pbc := mesh.PBC_code()
 	cfg := make3DConf(N)
-	k_exchangedecode_async(dst.DevPtr(0), unsafe.Pointer(Aex_red), regions.Ptr, wx, wy, wz, N[X], N[Y], N[Z], pbc, cfg)
+	k_exchangedecode_async(dst.DevPtr(0), unsafe.Pointer(Aex), regions.Ptr, wx, wy, wz, N[X], N[Y], N[Z], pbc, cfg)
 }
