@@ -4,16 +4,17 @@ package engine
 
 import (
 	"flag"
-	"github.com/mumax/3/cuda"
-	"github.com/mumax/3/util"
 	"os"
 	"path"
+
+	"github.com/mumax/3/cuda"
+	"github.com/mumax/3/util"
 )
 
 var (
 	// These flags are shared between cmd/mumax3 and Go input files.
 	Flag_cachedir    = flag.String("cache", os.TempDir(), "Kernel cache directory (empty disables caching)")
-	Flag_gpu         = flag.Int("gpu", 0, "Specify GPU")
+	Flag_gpu         = flag.Int("gpu", 0, "Specify a single GPU (use CUDA_AVAILABLE_DEVICES environment variable for advanced selection)")
 	Flag_interactive = flag.Bool("i", false, "Open interactive browser session")
 	Flag_od          = flag.String("o", "", "Override output directory")
 	Flag_port        = flag.String("http", ":35367", "Port to serve web gui")
@@ -23,6 +24,16 @@ var (
 	Flag_forceclean  = flag.Bool("f", false, "Force start, clean existing output directory")
 )
 
+func FlagPassed(name string) bool {
+	passed := false
+	flag.Visit(func(f *flag.Flag) {
+		if f.Name == name {
+			passed = true
+		}
+	})
+	return passed
+}
+
 // Usage: in every Go input file, write:
 //
 //	func main(){
